@@ -829,6 +829,7 @@ where
             Value::Tokens(n) => emit!(self, n),
             Value::Url(n) => emit!(self, n),
             Value::Delimiter(n) => emit!(self, n),
+            Value::Urange(n) => emit!(self, n),
         }
     }
 
@@ -1344,6 +1345,11 @@ where
         }
     }
 
+    #[emitter]
+    fn emit_urange(&mut self, n: &Urange) -> Result {
+        self.wr.write_raw(Some(n.span), &n.value)?;
+    }
+
     #[emitter]
     fn emit_selector_list(&mut self, n: &SelectorList) -> Result {
         self.emit_list(&n.children, ListFormat::CommaDelimited)?;
